Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(692)

Unified Diff: printing/backend/print_backend_dummy.cc

Issue 3945003: Move useful printing backend code from chrome/service/cloud_print to printing... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: resolve merge conflict Created 10 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « printing/backend/print_backend_cups.cc ('k') | printing/backend/print_backend_win.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: printing/backend/print_backend_dummy.cc
===================================================================
--- printing/backend/print_backend_dummy.cc (revision 0)
+++ printing/backend/print_backend_dummy.cc (working copy)
@@ -2,27 +2,22 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
// This is dummy implementation for all configurations where print system
// for cloud print is not available.
#if !defined(CP_PRINT_SYSTEM_AVAILABLE)
#include "chrome/service/cloud_print/print_system.h"
#include "base/logging.h"
-namespace cloud_print {
+namespace printing {
-std::string PrintSystem::GenerateProxyId() {
+scoped_refptr<PrintBackend> PrintBackend::CreateInstance(
+ const DictionaryValue* print_backend_settings) {
NOTREACHED();
- return std::string();
-}
-
-scoped_refptr<PrintSystem> PrintSystem::CreateInstance(
- const DictionaryValue* print_system_settings) {
- NOTREACHED();
return NULL;
}
-} // namespace cloud_print
-#endif // CP_PRINT_SYSTEM_AVAILABLE
+} // namespace printing
+#endif // PRINT_BACKEND_AVAILABLE
Property changes on: printing/backend/print_backend_dummy.cc
___________________________________________________________________
Added: svn:mergeinfo
@@ -2,27 +2,22 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-// This is dummy implementation for all configurations where print system
-// for cloud print is not available.
-#if !defined(CP_PRINT_SYSTEM_AVAILABLE)
+// This is dummy implementation for all configurations where there is no
+// print backend.
+#if !defined(PRINT_BACKEND_AVAILABLE)
-#include "chrome/service/cloud_print/print_system.h"
+#include "printing/backend/print_backend.h"
#include "base/logging.h"
« no previous file with comments | « printing/backend/print_backend_cups.cc ('k') | printing/backend/print_backend_win.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698